import { CoreClient } from './client.js';
import { ScriptWord, SigHashOptions, TxData, TxTemplate } from '@scrow/tapscript';
import { AddressConfig, AddressInfo, CmdConfig, MethodArgs, UTXO, WalletConfig, WalletInfo } from '../types/index.js';
export declare class CoreWallet {
    readonly _addrs: Map<string, string>;
    readonly _client: CoreClient;
    readonly _config: WalletConfig;
    readonly _label: string;
    _txfee?: number | null;
    constructor(client: CoreClient, label: string, config?: WalletConfig);
    get client(): CoreClient;
    get info(): Promise<WalletInfo>;
    get is_created(): Promise<boolean>;
    get is_loaded(): Promise<boolean>;
    get label(): string;
    get balance(): Promise<number>;
    get network(): string;
    get new_address(): Promise<string>;
    get new_scriptkey(): Promise<ScriptWord[]>;
    get utxos(): Promise<{
        sats: number;
        txid: string;
        vout: number;
        address: string;
        label: string;
        scriptPubKey: string;
        amount: number;
        confirmations: number;
        spendable: boolean;
        solvable: boolean;
        desc: string;
        parent_descs: string[];
        safe: boolean;
    }[]>;
    get xprvs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    get xpubs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    _create(): Promise<void>;
    _load(): Promise<void>;
    init(): Promise<void>;
    load(): Promise<void>;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, config?: Partial<CmdConfig>): Promise<T>;
    gen_address(config?: AddressConfig): Promise<string>;
    get_address(label: string): Promise<string>;
    parse_address(address: string): Promise<AddressInfo>;
    send_funds(amount: number, address: string, mine_block?: boolean): Promise<string>;
    ensure_funds(min_bal: number): Promise<void>;
    drain_faucet(amount: number, address?: string): Promise<string>;
    get_xprv(label: string): Promise<import("../types/descriptors.js").DescriptorData | undefined>;
    get_signer(desc: string): Promise<{
        pubkey: import("@cmdcode/buff").Buff;
        sign_tx: (txdata: TxData, config: SigHashOptions) => import("@cmdcode/buff").Buff;
    }>;
    create_txout(amount: number | bigint, address?: string): Promise<{
        value: bigint;
        scriptPubKey: ScriptWord[];
    }>;
    select_utxos(amount: number, sorter?: () => 1 | -1): Promise<UTXO[]>;
    fund_tx(templ: TxTemplate, config?: SigHashOptions, txfee?: number): Promise<TxData>;
}
//# sourceMappingURL=wallet.d.ts.map